<?php

/**
 * WebService SKYBOTAvailability - disponibilite du service SkyBoT
 *   NameSpace : https://ssp.imcce.fr/webservices/skybot/
 *   Method    : getAvailability
 *   URI       : skybotstatus_query.php[?<param>=<valeur>]
 *               avec param :
 *                  -mime     -> type mime de retour de la reponse: 'votable' (defaut), 'html', 'text'
 *                  -project  -> project name: sbot2 | sbotRosetta | sbotKepler  | sbotEarthL2 | sbotTESS | sbotS3M (default sbot2)
 *               Parametre additionnel:
 *                  -from     -> nom ou designation du service appelant transmis dans l'entete SOAP 
 *   Response  : Affiche les informations de statut de la BDD, avec
 *                  Availability   : statut de disponibilite
 *                  UpTime         : date depuis laquelle le service est accessible (N.A. si inconnue)
 *                  ValidTo        : date prevue d'une evenetuelle maintenance entrainant un arret du service (INF. si inconnue)
 *                  ContactDetails : informations de contact pour le service
 * 
 * @author J. Berthier (IMCCE/OBSPM) <berthier@imcce.fr> & F.Vachier (IMCCE/OBSPM) <fv@imcce.fr>
 * @copyright (C) 2005-2020, IMCCE
 * @since PHP7
 * @version 3.0
 */

// Client's ID 
$from = 'DemoClient';

// Input parameter
$param = array('mime'=>'text', 'project'=>'sbot2');

// Mise en cache ou non du WSDL du service
ini_set('soap.wsdl_cache_enabled', 1);

// Namespace et WSDL du service
$namespace = 'https://ssp.imcce.fr/webservices/skybot';
$uriwsdl   = $namespace.'/skybot.wsdl';

// Execution de la requete
try 
{
  // Instantiation du client
  $client = new SoapClient($uriwsdl, array('exceptions'=>1));
  // Parametres de l'entete SOAP
  $header = array('from'=>$from, 'hostip'=>'');
  // Construction de l'entete SOAP
  $client->__setSoapHeaders(array(new SOAPHeader($namespace, 'clientID', $header)));
  // Appel de la methode
  $response = $client->__soapCall('getAvailability', $param);
  // Affichage du resultat
  if ($param['mime'] == 'text')
  {
    header("HTTP/1.0 ".$response->status);
    header("Content-Type: text/plain");
    $res = explode(';', $response->result);
    $nbr = count($res);
    $newkey = array_keys($res);
    for ($i=0; $i<$nbr; $i++) { echo $res[$newkey[$i]].PHP_EOL; };
  }
  else if ($param['mime'] == 'json')
  {
    header("HTTP/1.0 ".$response->status);
    header("Content-Type: application/json");
    echo $response->result;
  }
  else
  {
    header("HTTP/1.0 ".$response->status);
    header("Content-Type: text/xml;content=x-votable");
    echo $response->result;
  }
} 
catch (SoapFault $fault) 
{
  trigger_error("SOAP Fault: {$fault->getTraceAsString()} (faultcode: {$fault->faultcode}, faultstring: {$fault->faultstring})", E_USER_ERROR);
}

?>
