<?php

/**
 * WebService SKYBOTStatus - statut de la base de donnees SkyBoT
 *   NameSpace : https://ssp.imcce.fr/webservices/skybot/
 *   Method    : skybotstatus
 *   URI       : skybotstatus_query.php[?<param>=<valeur>]
 *               avec param :
 *                  -mime     -> type mime de retour de la reponse: 'votable' (defaut), 'html', 'text'
 *                  -ep       -> epoque (optionnelle) pour laquelle on veut connaitre le statut de la BDD 
 *                  -project  -> project name: sbot2 | sbotRosetta | sbotKepler | sbotEarthL2 | sbotTESS | sbotS3M (default sbot2)
 *               Parametre additionnel:
 *                  -from     -> nom ou designation du service appelant transmis dans l'entete SOAP 
 *   Response  : Affiche les informations de statut de la BDD, avec
 *                  status     : 'ok', 'update in progress', 'stop'
 *                  date_deb   : date initiale de la periode couverte par la base
 *                  date_fin   : date finale de la periode couverte par la base
 *                  obj_aster  : nombre d'asteroides dans la base
 *                  obj_planet : nombre de planetes dans la base
 *                  obj_satel  : nombre de satellites naturel dans la base
 *                  obj_comet  : nombre de cometes dans la base
 *                  updated    : date de la derniere mise a jour
 * 
 * @author J. Berthier (IMCCE/OBSPM) <berthier@imcce.fr> & F.Vachier (IMCCE/OBSPM) <fv@imcce.fr>
 * @copyright (C) 2005-2020, IMCCE
 * @since PHP7
 * @version 3.0
 */

// Client's ID 
$from = 'DemoClient';

// Input parameter
$param = array('mime'=>'text', 'epoch'=>'xxx', 'project'=>'sbot2');

// Mise en cache ou non du WSDL du service
ini_set('soap.wsdl_cache_enabled', 0);

// Namespace et WSDL du service
$namespace = 'https://ssp.imcce.fr/webservices/skybot';
$namespace = 'http://ssp.localhost/webservices/skybot';
$uriwsdl = $namespace.'/skybot.wsdl';

// Execution de la requete
try 
{
  // Instantiation du client
  $client = new SoapClient($uriwsdl, array('exceptions'=>1));
  // Parametres de l'entete SOAP
  $header = array('from'=>$from, 'hostip'=>'');
  // Construction de l'entete SOAP
  $client->__setSoapHeaders(array(new SOAPHeader($namespace, 'clientID', $header)));
  // Appel de la methode
  $response = $client->__call('skybotstatus', $param);
  // Affichage du resultat
  if ($param['mime'] == 'text')
  {
    header("HTTP/1.0 ".$response->status);
    header("Content-Type: text/plain");
    $res = explode(';', $response->result);
    $nbr = count($res);
    $newkey = array_keys($res);
    for ($i=0; $i<$nbr; $i++) { echo $res[$newkey[$i]].PHP_EOL; };
	echo "STATUS: ".$response->status.PHP_EOL;
  }
  else if ($param['mime'] == 'json')
  {
    header("HTTP/1.0 ".$response->status);
    header("Content-Type: application/json");
    echo $response->result;
  }
  else
  {
    header("HTTP/1.0 ".$response->status);
    header("Content-Type: text/xml;content=x-votable");
    echo $response->result;
  }
} 
catch (SoapFault $fault) 
{
  trigger_error("SOAP Fault: {$fault->getTraceAsString()} (faultcode: {$fault->faultcode}, faultstring: {$fault->faultstring})", E_USER_ERROR);
}

?>
